Johnny Tests
============

Credit goes to Nathan Borror, who saved us the effort of coming up with a basic
application with which to test johnny.  The application here is the ``books``
application from his django-basic-apps_ application on git-hub.

.. _django-basic-apps: http://github.com/nathanborror/django-basic-apps

